<?xml version="1.0" encoding="utf-8"?>
<!-- © Sergey Ostanin <sergey_o@irenproject.ru> -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:output method="html" encoding="utf-8" doctype-public="-//W3C//DTD HTML 4.01//EN"/>

    <xsl:variable name="cellSpacing">10</xsl:variable>
    <xsl:param name="imageDir" select="'images'"/>
    <xsl:param name="title"/>

    <xsl:template match="text()"/>

    <xsl:template match="/irenTest">
        <html>
            <head>
                <title><xsl:value-of select="$title"/></title>
<style type="text/css">
<![CDATA[<!--
body {
    background-color: #FFFFFF;
    color: #000000;
}

img {
    vertical-align: middle;
    margin: 0.25em;
}

.sectionHeader {
    width: 100%;
    margin-top: 2em;
    margin-bottom: 2em;
    font-family: sans-serif;
    font-weight: bold;
    border-bottom-style: solid;
    border-bottom-color: #000000;
}

.questionHeader {
    font-size: smaller;
    width: 100%;
    margin-top: 2em;
    border-collapse: collapse;
}

.disabled {
    text-decoration: line-through;
}

@media screen {
    .enabled {
        background-color: #D3D3D3;
    }

    .disabled {
        background-color: #FFB6C1;
    }
}

@media print {
    .enabled, .disabled {
        border-top-style: solid;
        border-bottom-style: solid;
        border-color: #000000;
        border-width: 1px;
    }
}

.questionProperty {
    font-weight: bold;
}

.questionContent {
    margin-top: 0.25em;
    margin-bottom: 0px;
}

.choiceList {
    margin-top: 0.25em;
    margin-bottom: 0px;
}

.choice {
    margin-top: 0.5em;
    margin-bottom: 0.5em;
}

.correct {
    list-style-type: disc;
}

.incorrect {
    list-style-type: circle;
}

.patternItem {
    list-style-type: none;
    margin-top: 0.5em;
    margin-bottom: 0.5em;
}

.pattern {
    font-family: monospace;
    font-weight: bold;
}

.patternProperty {
    font-size: smaller;
    font-style: italic;
}

.cell {
    border-style: solid;
    border-width: 1px;
    padding: 0.25em;
}

@media screen {
    .cell {
        border-color: #C0C0C0;
    }
}

@media print {
    .cell {
        border-color: #000000;
    }
}

.sequenceNumber {
    font-style: italic;
    text-align: right;
}

.modifier {
    margin-top: 1em;
    margin-bottom: 1em;
    border-collapse: collapse;
}

.modifierHeader {
    font-size: smaller;
    font-weight: bold;
}

.boxless {
    border-bottom-style: solid;
    border-bottom-width: 1px;
    border-bottom-color: #000000;
}

.modifierBox {
    border-style: solid;
    border-width: 1px;
    border-color: #000000;
    padding: 0.25em;
}

.modifierLine {
    font-size: smaller;
}

.modifierProperty {
    font-weight: bold;
}

.profiles {
    margin-top: 2em;
    text-align: center;
    font-family: sans-serif;
    font-size: larger;
    font-weight: bold;
}

.profileTitle {
    margin-top: 2em;
    margin-bottom: 0.25em;
    font-family: sans-serif;
    font-weight: bold;
}

.profile {
    border-collapse: collapse;
}

.profilePart {
    font-size: smaller;
    font-weight: bold;
    text-align: center;
}

.profileLeft {
    vertical-align: top;
    text-align: right;
}

.profilePart, .profileLeft, .profileRight {
    border-style: solid;
    border-width: 1px;
    border-color: #000000;
    padding: 0.25em;
}

.profileCaption {
    font-style: italic;
}

.profileProperty {
    font-weight: bold;
}

.plainList {
    list-style-type: none;
    margin: 0px;
    padding: 0px;
}
-->]]>
</style>
            </head>
            <body>
                <xsl:apply-templates/>
                <xsl:if test="not (profiles or section//questions or section//modifiers)">
                    <p></p>
                </xsl:if>
            </body>
        </html>
    </xsl:template>

    <xsl:template match="section">
        <xsl:variable name="sectionTitle">
            <xsl:call-template name="getCurrentSectionTitle"/>
        </xsl:variable>
        <xsl:if test="(questions or modifiers) and string($sectionTitle)">
            <table class="sectionHeader"><tr><td>
                <xsl:copy-of select="$sectionTitle"/>
            </td></tr></table>
        </xsl:if>
        <xsl:apply-templates select="modifiers"/>
        <xsl:apply-templates select="questions | sections"/>
    </xsl:template>

    <xsl:template name="getCurrentSectionTitle">
        <xsl:for-each select="ancestor-or-self::section[position() &lt; last()]">
            <xsl:if test="position() != 1">
                <xsl:text> / </xsl:text>
            </xsl:if>
            <xsl:choose>
                <xsl:when test="string(@title)">
                    <xsl:value-of select="@title"/>
                </xsl:when>
                <xsl:otherwise>&lt;безымянный&gt;</xsl:otherwise>
            </xsl:choose>
        </xsl:for-each>
    </xsl:template>

    <xsl:template match="question">
        <xsl:variable name="headerClass">
            <xsl:if test="@enabled = 'true'">enabled</xsl:if>
            <xsl:if test="@enabled = 'false'">disabled</xsl:if>
        </xsl:variable>
        <table class="questionHeader"><tr>
            <td class="{$headerClass}">
                <xsl:text>Вопрос </xsl:text>
                <xsl:call-template name="getPrintableQuestionType">
                    <xsl:with-param name="type" select="@type"/>
                </xsl:call-template>

                <xsl:text> &#160;&#160;Вес: </xsl:text>
                <span class="questionProperty"><xsl:value-of select="@weight"/></span>

                <xsl:variable name="sectionTitle">
                    <xsl:call-template name="getCurrentSectionTitle"/>
                </xsl:variable>
                <xsl:if test="string($sectionTitle)">
                    <xsl:text> &#160;&#160;Раздел: </xsl:text>
                    <span class="questionProperty"><xsl:copy-of select="$sectionTitle"/></span>
                </xsl:if>

                <xsl:apply-templates select="labels"/>
            </td>
            <td align="right" class="{$headerClass}">Код: <span class="questionProperty"><xsl:value-of select="@id"/></span></td>
        </tr></table>

        <p class="questionContent"><xsl:apply-templates select="content"/></p>
        <xsl:apply-templates select="choices | patterns | pairs | sequence
            | distractors[not (preceding-sibling::pairs or preceding-sibling::sequence)]
            | categories | modifiers"/>
    </xsl:template>

    <xsl:template name="getPrintableQuestionType">
        <xsl:param name="type"/>

        <xsl:choose>
            <xsl:when test="$type = 'select'">с выбором ответа</xsl:when>
            <xsl:when test="$type = 'input'">с вводом ответа</xsl:when>
            <xsl:when test="$type = 'match'">на соответствие</xsl:when>
            <xsl:when test="$type = 'order'">на упорядочение</xsl:when>
            <xsl:when test="$type = 'classify'">на классификацию</xsl:when>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="labels">
        <xsl:text> &#160;&#160;Метки:</xsl:text>
        <span class="questionProperty"><xsl:apply-templates/></span>
    </xsl:template>

    <xsl:template match="label">
        <xsl:text> &#160;&#160;</xsl:text>
        <xsl:value-of select="@value"/>
    </xsl:template>

    <xsl:template match="content">
        <xsl:choose>
            <xsl:when test="text[normalize-space(@value)] | img | br">
                <xsl:apply-templates/>
            </xsl:when>
            <xsl:otherwise>&#160;</xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="text">
        <xsl:value-of select="@value"/>
    </xsl:template>

    <xsl:template match="img">
        <img src="{$imageDir}/{substring-after(@src, '/')}" alt=""/>
    </xsl:template>

    <xsl:template match="br">
        <br/>
    </xsl:template>

    <xsl:template match="choices">
        <ul class="choiceList"><xsl:apply-templates/></ul>
    </xsl:template>

    <xsl:template match="choice">
        <xsl:variable name="choiceClass">
            <xsl:if test="@correct = 'true'">correct</xsl:if>
            <xsl:if test="@correct = 'false'">incorrect</xsl:if>
        </xsl:variable>
        <li class="{$choiceClass} choice"><xsl:apply-templates/></li>
    </xsl:template>

    <xsl:template match="patterns">
        <ul><xsl:apply-templates/></ul>
    </xsl:template>

    <xsl:template match="pattern">
        <li class="patternItem">
            <span class="pattern"><xsl:value-of select="@value"/></span>
            <xsl:if test="@type = 'regexp'">
                <span class="patternProperty"> &#160;&#160;Регулярное выражение</span>
            </xsl:if>
            <xsl:if test="@precision != '0'">
                <span class="patternProperty"> &#160;&#160;&#177;<xsl:value-of select="@precision"/></span>
            </xsl:if>
            <xsl:if test="@quality != 1">
                <span class="patternProperty"> &#160;&#160;<xsl:value-of select="round(@quality * 100)"/>%</span>
            </xsl:if>
        </li>
    </xsl:template>

    <xsl:template match="pairs | sequence">
        <table cellspacing="{$cellSpacing}">
            <xsl:apply-templates/>
            <xsl:apply-templates select="../distractors" mode="continueTable"/>
        </table>
    </xsl:template>

    <xsl:template match="pair">
        <tr><xsl:apply-templates/></tr>
    </xsl:template>

    <xsl:template match="baseItem | matchingItem">
        <td class="cell"><xsl:apply-templates/></td>
    </xsl:template>

    <xsl:template match="sequenceItem">
        <tr>
            <td class="sequenceNumber"><xsl:number format="1."/></td>
            <td class="cell"><xsl:apply-templates/></td>
       </tr>
    </xsl:template>

    <xsl:template match="distractors" mode="continueTable">
        <tr>
            <td>&#160;</td>
            <td>&#160;</td>
        </tr>
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="distractors">
        <table cellspacing="{$cellSpacing}">
            <xsl:apply-templates/>
        </table>
    </xsl:template>

    <xsl:template match="distractor">
        <tr>
            <td/>
            <td class="cell"><xsl:apply-templates/></td>
        </tr>
    </xsl:template>

    <xsl:template match="categories">
        <table cellspacing="{$cellSpacing}">
            <xsl:apply-templates/>
        </table>
    </xsl:template>

    <xsl:template match="categoryTitle">
        <tr>
            <td class="cell"><xsl:apply-templates/></td>
            <td/>
        </tr>
    </xsl:template>

    <xsl:template match="categoryItem">
        <tr>
            <td/>
            <td class="cell"><xsl:apply-templates/></td>
        </tr>
    </xsl:template>

    <xsl:template match="modifier">
        <table class="modifier">
            <xsl:variable name="boxlessClass">
                <xsl:if test="(@type != 'setNegativeChoiceContent') and (@type != 'script')">boxless </xsl:if>
            </xsl:variable>
            <tr><td class="{$boxlessClass}modifierHeader">
                <xsl:choose>
                    <xsl:when test="@type = 'suppressSingleChoiceHint'">Запрет подсказки о единственном верном ответе</xsl:when>
                    <xsl:when test="@type = 'addNegativeChoice'">Добавление варианта "Верных ответов нет"</xsl:when>
                    <xsl:when test="@type = 'setNegativeChoiceContent'">Изменение текста варианта "Верных ответов нет"</xsl:when>
                    <xsl:when test="@type = 'shuffleChoices'">Перемешивание вариантов ответов</xsl:when>
                    <xsl:when test="@type = 'setEvaluationModel'">Настройка модели оценивания</xsl:when>
                    <xsl:when test="@type = 'setWeight'">Изменение веса вопроса</xsl:when>
                    <xsl:when test="@type = 'script'">Сценарий</xsl:when>
                </xsl:choose>
            </td></tr>
            <xsl:choose>
                <xsl:when test="@type = 'script'"><xsl:call-template name="scriptModifier"/></xsl:when>
                <xsl:when test="@type = 'setNegativeChoiceContent'"><xsl:call-template name="setNegativeChoiceContentModifier"/></xsl:when>
                <xsl:when test="@type = 'setWeight'"><xsl:call-template name="setWeightModifier"/></xsl:when>
                <xsl:when test="@type = 'setEvaluationModel'"><xsl:call-template name="setEvaluationModelModifier"/></xsl:when>
            </xsl:choose>
        </table>
    </xsl:template>

    <xsl:template name="scriptModifier">
        <tr><td class="modifierBox"><pre>
            <xsl:choose>
                <xsl:when test="script[normalize-space(@line)]">
                    <xsl:for-each select="script">
                        <xsl:if test="position() != 1">
                            <xsl:text>&#10;</xsl:text>
                        </xsl:if>
                        <xsl:value-of select="@line"/>
                    </xsl:for-each>
                </xsl:when>
                <xsl:otherwise>&#160;</xsl:otherwise>
            </xsl:choose>
        </pre></td></tr>
    </xsl:template>

    <xsl:template name="setNegativeChoiceContentModifier">
        <tr><td class="modifierBox">
            <xsl:apply-templates/>
        </td></tr>
    </xsl:template>

    <xsl:template name="setWeightModifier">
        <tr><td class="modifierLine">
            <xsl:text>Новый вес: </xsl:text>
            <span class="modifierProperty"><xsl:value-of select="@newWeight"/></span>
        </td></tr>
    </xsl:template>

    <xsl:template name="setEvaluationModelModifier">
        <tr><td class="modifierLine">
            <xsl:text>Оценивание: </xsl:text>
            <span class="modifierProperty">
                <xsl:choose>
                    <xsl:when test="@newEvaluationModel = 'dichotomic'">Жесткое</xsl:when>
                    <xsl:when test="@newEvaluationModel = 'lax'">Мягкое</xsl:when>
                </xsl:choose>
            </span>
            <xsl:if test="applyTo">
                <xsl:text> &#160;&#160;Применять к вопросам: </xsl:text>
                <span class="modifierProperty">
                    <xsl:for-each select="applyTo/questionType">
                        <xsl:if test="position() != 1">
                            <xsl:text>, </xsl:text>
                        </xsl:if>
                        <xsl:call-template name="getPrintableQuestionType">
                            <xsl:with-param name="type" select="@value"/>
                        </xsl:call-template>
                    </xsl:for-each>
                </span>
            </xsl:if>
        </td></tr>
    </xsl:template>

    <xsl:template match="profiles">
        <p class="profiles">Профили тестирования</p>
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="profile">
        <p class="profileTitle"><xsl:value-of select="@title"/></p>
        <table class="profile">
            <tr><td class="profilePart" colspan="2">Параметры</td></tr>
            <xsl:apply-templates select="questionSelection | sessionOptions | modifiers"/>
            <xsl:apply-templates select="testResults | markScale"/>
        </table>
    </xsl:template>

    <xsl:template match="questionSelection">
        <tr>
            <td class="profileLeft profileCaption">Выбор вопросов</td>
            <td class="profileRight">
                <ul class="plainList">
                    <li>
                        <xsl:choose>
                            <xsl:when test="@questionsPerSection = 'all'">
                                <span class="profileProperty">Все</span>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:text>По </xsl:text>
                                <span class="profileProperty"><xsl:value-of select="@questionsPerSection"/></span>
                                <xsl:text> из каждого раздела</xsl:text>
                            </xsl:otherwise>
                        </xsl:choose>

                        <xsl:if test="@labelFilter">
                            <xsl:text> с метками </xsl:text>
                            <span class="profileProperty"><xsl:value-of select="@labelFilter"/></span>
                        </xsl:if>
                    </li>

                    <xsl:if test="@shuffleQuestions = 'true'">
                        <li>Перемешивать вопросы</li>
                    </xsl:if>
                </ul>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="sessionOptions">
        <xsl:if test="@durationMinutes != 'unlimited'">
            <tr>
                <td class="profileLeft profileCaption">Ограничение времени</td>
                <td class="profileRight">
                    <span class="profileProperty"><xsl:value-of select="@durationMinutes"/></span>
                    <xsl:text> мин.</xsl:text>
                </td>
            </tr>
        </xsl:if>

        <xsl:if test="(@editableAnswers = 'true') or (../instantFeedback/@answerCorrectness = 'true')
            or (../instantFeedback/@totalPercentCorrect = 'true')">
            <tr>
                <td class="profileLeft profileCaption">Процесс тестирования</td>
                <td class="profileRight"><ul class="plainList">
                    <xsl:if test="@editableAnswers = 'true'"><li>Разрешить исправление ответов</li></xsl:if>
                    <xsl:if test="../instantFeedback/@answerCorrectness = 'true'"><li>Сообщать о правильности ответов</li></xsl:if>
                    <xsl:if test="../instantFeedback/@totalPercentCorrect = 'true'"><li>Показывать текущий результат в процентах</li></xsl:if>
                </ul></td>
            </tr>
        </xsl:if>

        <xsl:if test="(@browsableQuestions = 'true') or (@weightCues = 'true')">
            <tr>
                <td class="profileLeft profileCaption">Вид экрана тестируемого</td>
                <td class="profileRight"><ul class="plainList">
                    <xsl:if test="@browsableQuestions = 'true'"><li>Разрешить обзор вопросов</li></xsl:if>
                    <xsl:if test="@weightCues = 'true'"><li>Строить диаграмму с учетом весов вопросов</li></xsl:if>
                </ul></td>
            </tr>
        </xsl:if>
    </xsl:template>

    <xsl:template match="profile/modifiers">
        <tr>
            <td class="profileLeft profileCaption">Модификаторы</td>
            <td class="profileRight"><xsl:apply-templates/></td>
        </tr>
    </xsl:template>

    <xsl:template match="testResults">
        <tr><td class="profilePart" colspan="2">Результаты</td></tr>
        <xsl:if test="(@percentCorrect = 'true') or (@mark = 'true') or (@points = 'true')">
            <tr>
                <td class="profileLeft profileCaption">Общая информация</td>
                <td class="profileRight"><ul class="plainList">
                    <xsl:if test="@percentCorrect = 'true'"><li>Итог в процентах</li></xsl:if>
                    <xsl:if test="@mark = 'true'"><li>Оценка</li></xsl:if>
                    <xsl:if test="@points = 'true'"><li>Сумма набранных баллов</li></xsl:if>
                </ul></td>
            </tr>
        </xsl:if>
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="questionResults">
        <tr>
            <td class="profileLeft profileCaption">Подробности по вопросам</td>
            <td class="profileRight">
                <xsl:if test="(@percentCorrect = 'true') or (@correctAnswer = 'true') or (@points = 'true')">
                    <ul class="plainList">
                        <xsl:if test="@percentCorrect = 'true'"><li>Правильность ответа тестируемого</li></xsl:if>
                        <xsl:if test="@correctAnswer = 'true'"><li>Верный ответ</li></xsl:if>
                        <xsl:if test="@points = 'true'"><li>Вес вопроса</li></xsl:if>
                    </ul>
                </xsl:if>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="sectionResults">
        <tr>
            <td class="profileLeft profileCaption">Подробности по разделам</td>
            <td class="profileRight">
                <xsl:if test="(@percentCorrect = 'true') or (@points = 'true')
                    or (@questionCount = 'true') or (@questionList = 'true')">
                    <ul class="plainList">
                        <xsl:if test="@percentCorrect = 'true'"><li>Итог в процентах</li></xsl:if>
                        <xsl:if test="@points = 'true'"><li>Сумма набранных баллов</li></xsl:if>
                        <xsl:if test="@questionCount = 'true'"><li>Количество вопросов</li></xsl:if>
                        <xsl:if test="@questionList = 'true'"><li>Список вопросов</li></xsl:if>
                    </ul>
                </xsl:if>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="markScale">
        <tr><td class="profilePart" colspan="2">Шкала оценок</td></tr>
        <tr>
            <td class="profileLeft profileCaption">Нижняя граница, %</td>
            <td class="profileRight profileCaption">Оценка</td>
        </tr>
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="mark">
        <tr>
            <td class="profileLeft">
                <xsl:value-of select="round(@lowerBound * 10000) div 100"/>
            </td>
            <td class="profileRight">
                <xsl:value-of select="@title"/>
            </td>
        </tr>
    </xsl:template>
</xsl:stylesheet>
